@@ -4,7 +4,6 @@
 
 ;; Author: Daniel Pittman <daniel@danann.net>
 ;; Keywords: comm, processes
-;; Version: $Id: tramp-vc.el,v 1.5 2002/02/18 14:58:39 kaig Exp $
 
 ;; This file is part of GNU Emacs.
 
@@ -83,7 +82,7 @@ See `vc-do-command' for more information."
 	     (method (tramp-file-name-method v))
 	     (user (tramp-file-name-user v))
 	     (host (tramp-file-name-host v))
-	     (path (tramp-file-name-path v)))
+	     (localname (tramp-file-name-localname v)))
 	(set-buffer (get-buffer-create buffer))
 	(set (make-local-variable 'vc-parent-buffer) camefrom)
 	(set (make-local-variable 'vc-parent-buffer-name)
@@ -100,7 +99,7 @@ See `vc-do-command' for more information."
 		 (setq vc-file (vc-name file)))
 	    (setq squeezed
 		  (append squeezed
-			  (list (tramp-file-name-path
+			  (list (tramp-file-name-localname
 				 (tramp-dissect-file-name vc-file))))))
 	(if (and file (eq last 'WORKFILE))
 	    (progn
@@ -137,7 +136,8 @@ See `vc-do-command' for more information."
 	(goto-char (point-max))
 	(set-buffer-modified-p nil)
 	(forward-line -1)
-	(if (or (not (integerp status)) (and okstatus (< okstatus status)))
+	(if (or (not (integerp status))
+		(and (integerp okstatus) (< okstatus status)))
 	    (progn
 	      (pop-to-buffer buffer)
 	      (goto-char (point-min))
@@ -172,17 +172,19 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
              (method (when file (tramp-file-name-method v)))
              (user (when file (tramp-file-name-user v)))
              (host (when file (tramp-file-name-host v)))
-             (path (when file (tramp-file-name-path v))))
+             (localname (when file (tramp-file-name-localname v))))
       (setq squeezed (delq nil (copy-sequence flags)))
       (when file
-	(setq squeezed (append squeezed (list path))))
+	(setq squeezed (append squeezed (list (file-relative-name
+					       file default-directory)))))
       (let ((w32-quote-process-args t))
         (when (eq okstatus 'async)
           (message "Tramp doesn't do async commands, running synchronously."))
         (setq status (tramp-handle-shell-command
                       (mapconcat 'tramp-shell-quote-argument
                                  (cons command squeezed) " ") t))
-        (when (or (not (integerp status)) (and okstatus (< okstatus status)))
+        (when (or (not (integerp status))
+		  (and (integerp okstatus) (< okstatus status)))
           (pop-to-buffer (current-buffer))
           (goto-char (point-min))
           (shrink-window-if-larger-than-buffer)
@@ -192,7 +194,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
           (message "Running %s...OK" command))
       (vc-exec-after
        `(run-hook-with-args
-         'vc-post-command-functions ',command ',path ',flags))
+         'vc-post-command-functions ',command ',localname ',flags))
       status))))
 
 
@@ -249,7 +251,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
 	   (method (tramp-file-name-method v))
 	   (user (tramp-file-name-user v))
 	   (host (tramp-file-name-host v))
-	   (path (tramp-file-name-path v)))
+	   (localname (tramp-file-name-localname v)))
       (save-excursion (set-buffer (get-buffer-create "*vc-info*"))
 		      (erase-buffer))
       (let ((exec-path (append vc-path exec-path)) exec-status
@@ -273,7 +275,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
 	    ;; Actually execute remote command
 	    (tramp-handle-shell-command
 	     (mapconcat 'tramp-shell-quote-argument
-			(append (list command) args (list path)) " ")
+			(append (list command) args (list localname)) " ")
 	     (get-buffer-create"*vc-info*"))
 					;(tramp-wait-for-output)
 	    ;; Get status from command
@@ -282,6 +284,9 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
 	    (setq exec-status (read (current-buffer)))
 	    (message "Command %s returned status %d." command exec-status)))
       
+	;; Maybe okstatus can be `async' here.  But then, maybe the
+	;; async thing is new in Emacs 21, but this function is only
+	;; used in Emacs 20.
 	(cond ((> exec-status okstatus)
 	       (switch-to-buffer (get-file-buffer file))
 	       (shrink-window-if-larger-than-buffer
@@ -430,7 +435,7 @@ filename we are thinking about..."
                                      (tramp-file-name-method v)
                                      (tramp-file-name-user v)
                                      (tramp-file-name-host v))
-                 (tramp-shell-quote-argument (tramp-file-name-path v))))
+                 (tramp-shell-quote-argument (tramp-file-name-localname v))))
         (tramp-wait-for-output)
         ;; parse `ls -l' output ...
         ;; ... file mode flags
